reserve: Reserve
This function calculates the reserve given the reward matrix and some constant rate
This function requires proper construction of reward matrix as specified in the lecture notes provided in the course Liv1 at the University of Copenhagen.
Description
Reserve
This function calculates the reserve given the reward matrix and some constant rate
This function requires proper construction of reward matrix as specified in the lecture notes provided in the course Liv1 at the University of Copenhagen.